@@ -108,7 +108,7 @@ def get_backup_config():
     except:
         from ordereddict import OrderedDict
 
-    if duply_globals is not None:
+    if duply_globals is not None and os.path.exists(duply_globals):
         config = ConfigParser.RawConfigParser(dict_type=OrderedDict)
         try:
             config.read(duply_globals)
